summaryrefslogtreecommitdiff
path: root/guix.scm
diff options
context:
space:
mode:
Diffstat (limited to 'guix.scm')
-rw-r--r--guix.scm28
1 files changed, 14 insertions, 14 deletions
diff --git a/guix.scm b/guix.scm
index 92731d5..21460c6 100644
--- a/guix.scm
+++ b/guix.scm
@@ -1,20 +1,20 @@
-;;; Rabbit Prover --- Prove S-expression
-;;; Copyright © 2020 Masaya Tojo <masaya@tojo.tokyo>
+;;; Vikalpa --- Proof Assistant
+;;; Copyright © 2020, 2021 Masaya Tojo <masaya@tojo.tokyo>
;;;
;;; This file is part of Rabbit Prover.
;;;
;;; Rabbit Prover is free software; you can redistribute it and/or modify it
;;; under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 3 of the License, or
;;; (at your option) any later version.
;;;
;;; Rabbit Prover is distributed in the hope that it will be useful, but
;;; WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
;;; General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
-;;; along with Rabbit Prover. If not, see <http://www.gnu.org/licenses/>.
+;;; along with Vikalpa. If not, see <http://www.gnu.org/licenses/>.
(use-modules (guix packages)
((guix licenses) #:prefix license:)
@@ -26,11 +26,11 @@
(gnu packages pkg-config)
(gnu packages texinfo))
-(define guile-rabbit-prover
+(define guile-vikalpa
(package
- (name "guile-rabbit-prover")
- (version "0.0.0")
- (source (string-append (getcwd) "/rabbit-prover-" version ".tar.gz"))
+ (name "guile-vikalpa")
+ (version "0.1.0")
+ (source (string-append (getcwd) "/vikalpa-" version ".tar.gz"))
(build-system gnu-build-system)
(native-inputs
`(("autoconf" ,autoconf)
@@ -39,9 +39,9 @@
("texinfo" ,texinfo)))
(inputs
`(("guile" ,guile-3.0)))
- (synopsis "Prove S-expression")
- (description "Rabbit Prover is Prove S-expression.")
- (home-page "https://gitlab.com/tojoqk/rabbit-prover")
+ (synopsis "Proof Assistant")
+ (description "Vikalpa is Proof Assistant.")
+ (home-page "https://gitlab.com/tojoqk/vikalpa")
(license license:gpl3+)))
-guile-rabbit-prover
+guile-vikalpa
@@ -1,20 +1,20 @@
;;;
-;;; This file is part of Rabbit Prover.
+;;; This file is part of Vikalpa.
;;;
@@ -1,20 +1,20 @@
;;;
-;;; Rabbit Prover is free software; you can redistribute it and/or modify it
+;;; Vikalpa is free software; you can redistribute it and/or modify it
;;; under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 3 of the License, or
@@ -1,20 +1,20 @@
;;; (at your option) any later version.
;;;
-;;; Rabbit Prover is distributed in the hope that it will be useful, but
+;;; Vikalpa is distributed in the hope that it will be useful, but
;;; WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU